Lazy

Struct Lazy 

pub struct Lazy<V, F> { /* private fields */ }
A lazy-initialized view.

The view is only initialized when polled for a grant.

Implementations

Source

impl<V, F> Lazy<V, F>

pub fn new(init: F) -> Self

Create a new lazy view.

pub fn into_inner(self) -> Option<V>

Return the inner type, if it has been initialized.

Source

impl<V> Lazy<V, Box<dyn FnOnce() -> V>>

pub fn new_boxed(init: impl FnOnce() -> V + 'static) -> Self

Available on crate features std only.

Create a new lazy view with a boxed initialization function.